==> jc-1.4.0.tar.gz: org/w3c/dom/xpath/XPathException.h <==
// public class org.w3c.dom.xpath.XPathException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fa6be350dd4943fb org_w3c_dom_xpath_XPathException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_org_w3c_dom_xpath_XPathException_H_
#define _JC_org_w3c_dom_xpath_XPathException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_w3c_dom_xpath_XPathException$sub_refs	_jc_org_w3c_dom_xpath_XPathException$sub_refs;
typedef struct _jc_org_w3c_dom_xpath_XPathException$sub_nonrefs	_jc_org_w3c_dom_xpath_XPathException$sub_nonrefs;
typedef struct _jc_org_w3c_dom_xpath_XPathException$refs	_jc_org_w3c_dom_xpath_XPathException$refs;
typedef struct _jc_org_w3c_dom_xpath_XPathException$nonrefs	_jc_org_w3c_dom_xpath_XPathException$nonrefs;
typedef struct _jc_org_w3c_dom_xpath_XPathException$object	_jc_org_w3c_dom_xpath_XPathException$object;

typedef struct _jc_org_w3c_dom_xpath_XPathException$fields_struct	_jc_org_w3c_dom_xpath_XPathException$fields_struct;
typedef const struct _jc_org_w3c_dom_xpath_XPathException$vmethods	_jc_org_w3c_dom_xpath_XPathException$vmethods;
typedef const struct _jc_org_w3c_dom_xpath_XPathException$vtable	_jc_org_w3c_dom_xpath_XPathException$vtable;
typedef const struct _jc_org_w3c_dom_xpath_XPathException$vtype	_jc_org_w3c_dom_xpath_XPathException$vtype;

// Class fields structure
struct _jc_org_w3c_dom_xpath_XPathException$fields_struct {
	jshort	INVALID__5fEXPRESSION__5fERR;
	jshort	TYPE__5fERR;
};
extern _jc_org_w3c_dom_xpath_XPathException$fields_struct _jc_org_w3c_dom_xpath_XPathException$class_fields;

// Constructors
extern void _jc_org_w3c_dom_xpath_XPathException$method$_init$f5cdf9de5128930c(_jc_env *, struct _jc_org_w3c_dom_xpath_XPathException$object *, jshort, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_org_w3c_dom_xpath_XPathException$vmethods {
};

// Vtable
struct _jc_org_w3c_dom_xpath_XPathException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_xpath_XPathException$vmethods	org_w3c_dom_xpath_XPathException;
};

// Vtype
struct _jc_org_w3c_dom_xpath_XPathException$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_xpath_XPathException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_xpath_XPathException$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_xpath_XPathException$refs {
    _jc_org_w3c_dom_xpath_XPathException$sub_refs	org_w3c_dom_xpath_XPathException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_xpath_XPathException$sub_nonrefs {
	jshort	code;
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_xpath_XPathException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_xpath_XPathException$sub_nonrefs	org_w3c_dom_xpath_XPathException;
};

// Object instance structure
struct _jc_org_w3c_dom_xpath_XPathException$object {
	_jc_org_w3c_dom_xpath_XPathException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_xpath_XPathException$vtype	*vtype;
	_jc_org_w3c_dom_xpath_XPathException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_xpath_XPathException$vtype _jc_org_w3c_dom_xpath_XPathException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_xpath_XPathException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_xpath_XPathException$class_object;

#endif	/* _JC_org_w3c_dom_xpath_XPathException_H_ */

==> jc-1.4.6.tar.gz: org/w3c/dom/xpath/XPathException.h <==
// public class org.w3c.dom.xpath.XPathException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fa6be350dd4943fb org_w3c_dom_xpath_XPathException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_org_w3c_dom_xpath_XPathException_H_
#define _JC_org_w3c_dom_xpath_XPathException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_w3c_dom_xpath_XPathException$sub_refs	_jc_org_w3c_dom_xpath_XPathException$sub_refs;
typedef struct _jc_org_w3c_dom_xpath_XPathException$sub_nonrefs	_jc_org_w3c_dom_xpath_XPathException$sub_nonrefs;
typedef struct _jc_org_w3c_dom_xpath_XPathException$refs	_jc_org_w3c_dom_xpath_XPathException$refs;
typedef struct _jc_org_w3c_dom_xpath_XPathException$nonrefs	_jc_org_w3c_dom_xpath_XPathException$nonrefs;
typedef struct _jc_org_w3c_dom_xpath_XPathException$object	_jc_org_w3c_dom_xpath_XPathException$object;

typedef struct _jc_org_w3c_dom_xpath_XPathException$fields_struct	_jc_org_w3c_dom_xpath_XPathException$fields_struct;
typedef const struct _jc_org_w3c_dom_xpath_XPathException$vmethods	_jc_org_w3c_dom_xpath_XPathException$vmethods;
typedef const struct _jc_org_w3c_dom_xpath_XPathException$vtable	_jc_org_w3c_dom_xpath_XPathException$vtable;
typedef const struct _jc_org_w3c_dom_xpath_XPathException$vtype	_jc_org_w3c_dom_xpath_XPathException$vtype;

// Class fields structure
struct _jc_org_w3c_dom_xpath_XPathException$fields_struct {
	jshort	INVALID__5fEXPRESSION__5fERR;
	jshort	TYPE__5fERR;
};
extern _jc_org_w3c_dom_xpath_XPathException$fields_struct _jc_org_w3c_dom_xpath_XPathException$class_fields;

// Constructors
extern void _jc_org_w3c_dom_xpath_XPathException$method$_init$f5cdf9de5128930c(_jc_env *, struct _jc_org_w3c_dom_xpath_XPathException$object *, jshort, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_w3c_dom_xpath_XPathException$vmethods {
};

// Vtable
struct _jc_org_w3c_dom_xpath_XPathException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_xpath_XPathException$vmethods	org_w3c_dom_xpath_XPathException;
};

// Vtype
struct _jc_org_w3c_dom_xpath_XPathException$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_xpath_XPathException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_xpath_XPathException$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_xpath_XPathException$refs {
    _jc_org_w3c_dom_xpath_XPathException$sub_refs	org_w3c_dom_xpath_XPathException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_xpath_XPathException$sub_nonrefs {
	jshort	code;
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_xpath_XPathException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_xpath_XPathException$sub_nonrefs	org_w3c_dom_xpath_XPathException;
};

// Object instance structure
struct _jc_org_w3c_dom_xpath_XPathException$object {
	_jc_org_w3c_dom_xpath_XPathException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_xpath_XPathException$vtype	*vtype;
	_jc_org_w3c_dom_xpath_XPathException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_xpath_XPathException$vtype _jc_org_w3c_dom_xpath_XPathException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_xpath_XPathException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_xpath_XPathException$class_object;

#endif	/* _JC_org_w3c_dom_xpath_XPathException_H_ */
